==> developer-center-api-1.6.5-20170117.115243-1-sources.jar: cn/com/duiba/developer/center/api/domain/dto/RechargeOrdersDto.java <==
package cn.com.duiba.developer.center.api.domain.dto;

import java.util.Date;

import cn.com.duiba.developer.center.api.domain.BaseDO;
/**
 * 充值订单Dto
 * Name：cn.com.duiba.developer.center.api.domain.dataobject.RechargeOrdersDto.java
 * Description：
 * Author：zhengjy
 * Create Time：2016年7月25日 下午3:29:53
 */
public class RechargeOrdersDto extends BaseDO {
    private static final long serialVersionUID = -382726975498091789L;

    public static final String StatusCreate = "create"; // 创建订单
    public static final String StatusSuccess = "success";// 第三方充值成功
    public static final String StatusFail = "fail";// 第三方充值失败
    public static final String StatusCharged = "charged"; // 本地记账

    public static final String TradeWaitPay = "TRADE_WAIT_PAY";
    public static final String TradeFinished = "TRADE_FINISHED";
    public static final String TypeEbatong="ebatong";// 贝付科技 充值

    public static final String JsonKey_AccountType = "accountType";//用户的充值类型 枚举:company self
    public static final String JsonKey_Name = "name";//公司的名称或者个人用户的真实姓名
    public static final String JsonKey_License = "license";//公司的营业执照号
    public static final String JsonKey_Time = "time";//公司的执照到期时间
    public static final String JsonKay_IdNum = "idNum";//个人用户的身份证号


    private Long id;
    private String orderNum;// 订单号
    private Long devId;// 开发者ID

    private String devIp; // 充值用户IP
    private String defaultBank;// 默认银行

    private String type;// 充值类型 贝付科技：ebatong

    private Long totalFee; // 总价 单位分 上游提交的金额 包含手续费
    private Long chargeMoney; // 充值金额
    private String payUrl;// 充值连接
    private String tradeStatus;// 上游处理状态
    private String tradeNo;// 上游订单号
    private String supplierInfo;

    private String status;// 处理中 成功 失败
    private String errorMessage;// 系统错误
    private String failReason;// 失败原因，主要是给用户看的

    private Date finishTime; // 订单结束时间

    private String brief;

    private String json;//拓展字段,数据库长度255,当前使用最多90

    private Date gmtCreate;
    private Date gmtModified;
    /**
     * 无参构造函数
     */
    public RechargeOrdersDto(){
        toBeUpdate = false;
        toBeInsert = false;
    }
    /**
     * 更新构造函数
     * @param id 实体Id
     */
    public RechargeOrdersDto(Long id) {
        this.id = id;
        this.gmtModified = new Date();
        toBeUpdate = true;
    }
    /**
     * 插入构造函数
     * @param init4insert
     */
    public RechargeOrdersDto(boolean init4insert) {
        if (init4insert) {
            toBeInsert = true;
            gmtCreate = new Date();
            gmtModified = gmtCreate;
        }
    }

    public String getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }

    public Long getDevId() {
        return devId;
    }

    public void setDevId(Long devId) {
        this.devId = devId;
    }

    public String getDevIp() {
        return devIp;
    }

    public void setDevIp(String devIp) {
        this.devIp = devIp;
    }

    public String getDefaultBank() {
        return defaultBank;
    }

    public void setDefaultBank(String defaultBank) {
        this.defaultBank = defaultBank;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public Long getTotalFee() {
        return totalFee;
    }

    public void setTotalFee(Long totalFee) {
        this.totalFee = totalFee;
    }

    public Long getChargeMoney() {
        return chargeMoney;
    }

    public void setChargeMoney(Long chargeMoney) {
        this.chargeMoney = chargeMoney;
    }

    public String getPayUrl() {
        return payUrl;
    }

    public void setPayUrl(String payUrl) {
        this.payUrl = payUrl;
    }

    public String getTradeStatus() {
        return tradeStatus;
    }

    public void setTradeStatus(String tradeStatus) {
        this.tradeStatus = tradeStatus;
    }

    public String getTradeNo() {
        return tradeNo;
    }

    public void setTradeNo(String tradeNo) {
        this.tradeNo = tradeNo;
    }

    public String getSupplierInfo() {
        return supplierInfo;
    }

    public void setSupplierInfo(String supplierInfo) {
        this.supplierInfo = supplierInfo;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }

    public String getFailReason() {
        return failReason;
    }

    public void setFailReason(String failReason) {
        this.failReason = failReason;
    }

    public Date getFinishTime() {
        return finishTime;
    }

    public void setFinishTime(Date finishTime) {
        this.finishTime = finishTime;
    }

    public String getBrief() {
        return brief;
    }

    public void setBrief(String brief) {
        this.brief = brief;
    }

    public String getJson() {
        return json;
    }

    public void setJson(String json) {
        this.json = json;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }
}

==> developer-center-api-3.3.6-ar-20181204.065042-1-sources.jar: cn/com/duiba/developer/center/api/domain/dto/RechargeOrdersDto.java <==
package cn.com.duiba.developer.center.api.domain.dto;

import java.util.Date;

import cn.com.duiba.developer.center.api.domain.BaseDO;
/**
 * 充值订单Dto
 * Name：cn.com.duiba.developer.center.api.domain.dataobject.RechargeOrdersDto.java
 * Description：
 * Author：zhengjy
 * Create Time：2016年7月25日 下午3:29:53
 */
public class RechargeOrdersDto extends BaseDO {
    private static final long serialVersionUID = -382726975498091789L;

    public static final String StatusCreate = "create"; // 创建订单
    public static final String StatusSuccess = "success";// 第三方充值成功
    public static final String StatusFail = "fail";// 第三方充值失败
    public static final String StatusCharged = "charged"; // 本地记账

    public static final String TradeWaitPay = "TRADE_WAIT_PAY";
    public static final String TradeFinished = "TRADE_FINISHED";
    public static final String TypeEbatong="ebatong";// 贝付科技 充值
    public static final String TypeAlipay="alipay";//支付宝充值

    public static final String JsonKey_AccountType = "accountType";//用户的充值类型 枚举:company self
    public static final String JsonKey_Name = "name";//公司的名称或者个人用户的真实姓名
    public static final String JsonKey_License = "license";//公司的营业执照号
    public static final String JsonKey_Time = "time";//公司的执照到期时间
    public static final String JsonKay_IdNum = "idNum";//个人用户的身份证号


    private Long id;
    private String orderNum;// 订单号
    private Long devId;// 开发者ID

    private String devIp; // 充值用户IP
    private String defaultBank;// 默认银行

    private String type;// 充值类型 贝付科技：ebatong

    private Long totalFee; // 总价 单位分 上游提交的金额 包含手续费
    private Long chargeMoney; // 充值金额
    private String payUrl;// 充值连接
    private String tradeStatus;// 上游处理状态
    private String tradeNo;// 上游订单号
    private String supplierInfo;

    private String status;// 处理中 成功 失败
    private String errorMessage;// 系统错误
    private String failReason;// 失败原因，主要是给用户看的

    private Date finishTime; // 订单结束时间

    private String brief;

    private String json;//拓展字段,数据库长度255,当前使用最多90

    private Long appId; // 开发者应用ID

    private Date gmtCreate;
    private Date gmtModified;
    /**
     * 无参构造函数
     */
    public RechargeOrdersDto(){
        toBeUpdate = false;
        toBeInsert = false;
    }
    /**
     * 更新构造函数
     * @param id 实体Id
     */
    public RechargeOrdersDto(Long id) {
        this.id = id;
        this.gmtModified = new Date();
        toBeUpdate = true;
    }
    /**
     * 插入构造函数
     * @param init4insert
     */
    public RechargeOrdersDto(boolean init4insert) {
        if (init4insert) {
            toBeInsert = true;
            gmtCreate = new Date();
            gmtModified = gmtCreate;
        }
    }

    public String getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }

    public Long getDevId() {
        return devId;
    }

    public void setDevId(Long devId) {
        this.devId = devId;
    }

    public String getDevIp() {
        return devIp;
    }

    public void setDevIp(String devIp) {
        this.devIp = devIp;
    }

    public String getDefaultBank() {
        return defaultBank;
    }

    public void setDefaultBank(String defaultBank) {
        this.defaultBank = defaultBank;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public Long getTotalFee() {
        return totalFee;
    }

    public void setTotalFee(Long totalFee) {
        this.totalFee = totalFee;
    }

    public Long getChargeMoney() {
        return chargeMoney;
    }

    public void setChargeMoney(Long chargeMoney) {
        this.chargeMoney = chargeMoney;
    }

    public String getPayUrl() {
        return payUrl;
    }

    public void setPayUrl(String payUrl) {
        this.payUrl = payUrl;
    }

    public String getTradeStatus() {
        return tradeStatus;
    }

    public void setTradeStatus(String tradeStatus) {
        this.tradeStatus = tradeStatus;
    }

    public String getTradeNo() {
        return tradeNo;
    }

    public void setTradeNo(String tradeNo) {
        this.tradeNo = tradeNo;
    }

    public String getSupplierInfo() {
        return supplierInfo;
    }

    public void setSupplierInfo(String supplierInfo) {
        this.supplierInfo = supplierInfo;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }

    public String getFailReason() {
        return failReason;
    }

    public void setFailReason(String failReason) {
        this.failReason = failReason;
    }

    public Date getFinishTime() {
        return finishTime;
    }

    public void setFinishTime(Date finishTime) {
        this.finishTime = finishTime;
    }

    public String getBrief() {
        return brief;
    }

    public void setBrief(String brief) {
        this.brief = brief;
    }

    public String getJson() {
        return json;
    }

    public void setJson(String json) {
        this.json = json;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }
}
